@@ -10,8 +10,15 @@ from .dtypes import _INDEX, FP64, lookup_dtype, unify
 from .exceptions import DimensionMismatch, NoValue, check_status
 from .expr import AmbiguousAssignOrExtract, IndexerResolver, Updater
 from .mask import StructuralMask, ValueMask
-from .operator import get_semiring, get_typed_op
-from .scalar import _MATERIALIZE, Scalar, ScalarExpression, _as_scalar, _scalar_index
+from .operator import find_opclass, get_semiring, get_typed_op, op_from_string
+from .scalar import (
+    _MATERIALIZE,
+    Scalar,
+    ScalarExpression,
+    ScalarIndexExpr,
+    _as_scalar,
+    _scalar_index,
+)
 from .utils import (
     _CArray,
     _Pointer,
@@ -21,7 +28,7 @@ from .utils import (
     values_to_numpy_buffer,
     wrapdoc,
 )
-from .vector import Vector, VectorExpression
+from .vector import Vector, VectorExpression, VectorIndexExpr
 
 ffi_new = ffi.new
 
@@ -31,7 +38,7 @@ def _m_add_v(updater, left, right, op):
     full = Vector(right.dtype, left._nrows, name="v_full")
     full[:] = 0
     temp = full.outer(right, binary.second).new(name="M_temp", mask=updater.kwargs.get("mask"))
-    updater << left.ewise_add(temp, op, require_monoid=False)
+    updater << left.ewise_add(temp, op)
 
 
 def _m_mult_v(updater, left, right, op):
@@ -142,12 +149,8 @@ class Matrix(BaseType):
         resolved_indexes = IndexerResolver(self, keys)
         shape = resolved_indexes.shape
         if not shape:
-            from .scalar import ScalarIndexExpr
-
             return ScalarIndexExpr(self, resolved_indexes)
         elif len(shape) == 1:
-            from .vector import VectorIndexExpr
-
             return VectorIndexExpr(self, resolved_indexes, *shape)
         else:
             return MatrixIndexExpr(self, resolved_indexes, *shape)
@@ -390,6 +393,20 @@ class Matrix(BaseType):
         # TODO: expose COMPLETE or MATERIALIZE options to the user
         call("GrB_Matrix_wait", [self, _MATERIALIZE])
 
+    def get(self, row, col, default=None):
+        """Get an element at row, col indices as a Python scalar.
+
+        If there is no element at ``matrix[row, col]``, then the default value is returned.
+        """
+        expr = self[row, col]
+        if expr._is_scalar:
+            rv = expr.new().value
+            return default if rv is None else rv
+        raise ValueError(
+            "Bad row, col arguments in Matrix.get(...).  "
+            "Indices should get a single element, which will be extracted as a Python scalar."
+        )
+
     @classmethod
     def new(cls, dtype, nrows=0, ncols=0, *, name=None):
         """
@@ -463,7 +480,7 @@ class Matrix(BaseType):
     # to __setitem__ to trigger a call to GraphBLAS
     #########################################################
 
-    def ewise_add(self, other, op=monoid.plus, *, require_monoid=True):
+    def ewise_add(self, other, op=monoid.plus, *, require_monoid=None):
         """
         GrB_Matrix_eWiseAdd
 
@@ -471,9 +488,8 @@ class Matrix(BaseType):
 
         Default op is monoid.plus.
 
-        Unless explicitly disabled, this method requires a monoid (directly or from a semiring).
-        The reason for this is that binary operators can create very confusing behavior when
-        only one of the two elements is present.
+        *Warning*: using binary operators can create very confusing behavior
+        when only one of the two elements is present.
 
         Examples:
             - binary.minus where left=N/A and right=4 yields 4 rather than -4 as might be expected
@@ -482,8 +498,15 @@ class Matrix(BaseType):
 
         The behavior is caused by grabbing the non-empty value and using it directly without
         performing any operation. In the case of `gt`, the non-empty value is cast to a boolean.
-        For these reasons, users are required to be explicit when choosing this surprising behavior.
         """
+        if require_monoid is not None:
+            warnings.warn(
+                "require_monoid keyword is deprecated; "
+                "future behavior will be like `require_monoid=False`",
+                DeprecationWarning,
+            )
+        else:
+            require_monoid = False
         method_name = "ewise_add"
         other = self._expect_type(
             other,
@@ -740,11 +763,23 @@ class Matrix(BaseType):
         Apply UnaryOp to each element of the calling Matrix
         A BinaryOp can also be applied if a scalar is passed in as `left` or `right`,
             effectively converting a BinaryOp into a UnaryOp
+        An IndexUnaryOp can also be applied with the thunk passed in as `right`
         """
         method_name = "apply"
         extra_message = (
-            "apply only accepts UnaryOp with no scalars or BinaryOp with `left` or `right` scalar."
+            "apply only accepts UnaryOp with no scalars or BinaryOp with `left` or `right` scalar "
+            "or IndexUnaryOp with `right` thunk."
         )
+        if isinstance(op, str):
+            op = op_from_string(op)
+        op, opclass = find_opclass(op)
+        if opclass in {"IndexUnaryOp", "SelectOp"}:
+            # Provide default value for index unary
+            if right is None:
+                right = False  # most basic form of 0 when unifying dtypes
+            if left is not None:
+                raise TypeError("Do not pass `left` when applying IndexUnaryOp")
+
         if left is None and right is None:
             op = get_typed_op(op, self.dtype, kind="unary")
             self._expect_op(
@@ -772,7 +807,7 @@ class Matrix(BaseType):
                         op=op,
                     )
             op = get_typed_op(op, left.dtype, self.dtype, is_left_scalar=True, kind="binary")
-            if op.opclass == "Monoid":
+            if opclass == "Monoid":
                 op = op.binaryop
             else:
                 self._expect_op(
@@ -795,7 +830,7 @@ class Matrix(BaseType):
             expr_repr = "{1.name}.apply({op}, left={0._expr_name})"
         elif left is None:
             if type(right) is not Scalar:
-                dtype = self.dtype if self.dtype._is_udt else None
+                dtype = self.dtype if (self.dtype._is_udt and not op.is_positional) else None
                 try:
                     right = Scalar.from_value(right, dtype, is_cscalar=None, name="")
                 except TypeError:
@@ -807,26 +842,33 @@ class Matrix(BaseType):
                         extra_message="Literal scalars also accepted.",
                         op=op,
                     )
-            op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
-            if op.opclass == "Monoid":
-                op = op.binaryop
-            else:
-                self._expect_op(
-                    op,
-                    "BinaryOp",
-                    within=method_name,
-                    argname="op",
-                    extra_message=extra_message,
+            if opclass in {"IndexUnaryOp", "SelectOp"}:
+                op = get_typed_op(
+                    op, self.dtype, right.dtype, is_right_scalar=True, kind="indexunary"
                 )
+                cfunc_method = "IndexOp"
+            else:
+                op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
+                cfunc_method = "BinaryOp2nd"
+                if opclass == "Monoid":
+                    op = op.binaryop
+                else:
+                    self._expect_op(
+                        op,
+                        "BinaryOp",
+                        within=method_name,
+                        argname="op",
+                        extra_message=extra_message,
+                    )
             if right._is_cscalar:
                 if right.dtype._is_udt:
                     dtype_name = "UDT"
                     right = _Pointer(right)
                 else:
                     dtype_name = right.dtype.name
-                cfunc_name = f"GrB_Matrix_apply_BinaryOp2nd_{dtype_name}"
+                cfunc_name = f"GrB_Matrix_apply_{cfunc_method}_{dtype_name}"
             else:
-                cfunc_name = "GrB_Matrix_apply_BinaryOp2nd_Scalar"
+                cfunc_name = f"GrB_Matrix_apply_{cfunc_method}_Scalar"
             args = [self, right]
             expr_repr = "{0.name}.apply({op}, right={1._expr_name})"
         else:
@@ -1576,6 +1618,7 @@ class MatrixExpression(BaseExpression):
     ewise_mult = wrapdoc(Matrix.ewise_mult)(property(_automethods.ewise_mult))
     ewise_union = wrapdoc(Matrix.ewise_union)(property(_automethods.ewise_union))
     gb_obj = wrapdoc(Matrix.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Matrix.get)(property(_automethods.get))
     isclose = wrapdoc(Matrix.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Matrix.isequal)(property(_automethods.isequal))
     kronecker = wrapdoc(Matrix.kronecker)(property(_automethods.kronecker))
@@ -1656,6 +1699,7 @@ class MatrixIndexExpr(AmbiguousAssignOrExtract):
     ewise_mult = wrapdoc(Matrix.ewise_mult)(property(_automethods.ewise_mult))
     ewise_union = wrapdoc(Matrix.ewise_union)(property(_automethods.ewise_union))
     gb_obj = wrapdoc(Matrix.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Matrix.get)(property(_automethods.get))
     isclose = wrapdoc(Matrix.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Matrix.isequal)(property(_automethods.isequal))
     kronecker = wrapdoc(Matrix.kronecker)(property(_automethods.kronecker))
@@ -1799,6 +1843,7 @@ class TransposedMatrix:
     __ixor__ = _automethods.__ixor__
 
     # Misc.
+    get = Matrix.get
     isequal = Matrix.isequal
     isclose = Matrix.isclose
     wait = Matrix.wait
