@@ -9,7 +9,7 @@ import pytest
 from numpy.testing import assert_array_equal
 
 import graphblas
-from graphblas import agg, binary, dtypes, monoid, select, semiring, unary
+from graphblas import agg, binary, dtypes, indexunary, monoid, select, semiring, unary
 from graphblas.exceptions import (
     DimensionMismatch,
     EmptyObject,
@@ -20,7 +20,7 @@ from graphblas.exceptions import (
 
 from .conftest import autocompute, compute
 
-from graphblas import Matrix, Scalar, Vector  # isort:skip
+from graphblas import Matrix, Scalar, Vector  # isort:skip (for dask-graphblas)
 
 
 @pytest.fixture
@@ -374,15 +374,15 @@ def test_ewise_add(v):
     # Binary, Monoid, and Semiring
     v2 = Vector.from_values([0, 3, 5, 6], [2, 3, 2, 1])
     result = Vector.from_values([0, 1, 3, 4, 5, 6], [2, 1, 3, 2, 2, 1])
-    with pytest.raises(TypeError, match="require_monoid"):
-        v.ewise_add(v2, binary.minus)
+    # with pytest.raises(TypeError, match="require_monoid"):
+    v.ewise_add(v2, binary.minus)  # okay now
     w = v.ewise_add(v2, binary.max).new()  # ok if the binaryop is part of a monoid
     assert w.isequal(result)
-    w = v.ewise_add(v2, binary.max, require_monoid=False).new()
+    w = v.ewise_add(v2, binary.max).new()
     assert w.isequal(result)
     w.update(v.ewise_add(v2, monoid.max))
     assert w.isequal(result)
-    with pytest.raises(TypeError, match="Expected type: Monoid"):
+    with pytest.raises(TypeError, match="Expected type: BinaryOp, Monoid"):
         v.ewise_add(v2, semiring.max_times)
     # default is plus
     w = v.ewise_add(v2).new()
@@ -393,8 +393,8 @@ def test_ewise_add(v):
     b2 = Vector.from_values([0, 1, 2, 3], [True, True, False, False])
     with pytest.raises(KeyError, match="plus does not work"):
         b1.ewise_add(b2).new()
-    with pytest.raises(TypeError, match="for BOOL datatype"):
-        binary.plus(b1 | b2)
+    # with pytest.raises(TypeError, match="for BOOL datatype"):
+    binary.plus(b1 | b2)  # now okay (btw, `binary.plus[bool].monoid is None`)
 
 
 def test_extract(v):
@@ -647,14 +647,37 @@ def test_apply_empty(v):
         v.apply(binary.plus, s).new()
 
 
+def test_apply_indexunary(v):
+    idx = [1, 3, 4, 6]
+    vr = Vector.from_values(idx, idx)
+    r1 = v.apply(indexunary.index).new()
+    r2 = v.apply("index").new()
+    r3 = indexunary.index(v).new()
+    assert r1.isequal(vr)
+    assert r2.isequal(vr)
+    assert r3.isequal(vr)
+
+    v2 = Vector.from_values(idx, [False, False, True, False])
+    s2 = Scalar(dtypes.INT64)
+    s2.value = 2
+    w1 = v.apply("==", s2).new()
+    w2 = v.apply(indexunary.valueeq, s2).new()
+    w3 = v.apply(select.valueeq, s2).new()
+    w4 = indexunary.valueeq(v, s2).new()
+    assert w1.isequal(v2)
+    assert w2.isequal(v2)
+    assert w3.isequal(v2)
+    assert w4.isequal(v2)
+
+
 def test_select(v):
     result = Vector.from_values([1, 3], [1, 1], size=7)
     w1 = v.select(select.valueeq, 1).new()
     w2 = v.select("==", 1).new()
     w3 = select.rowle(v, 3).new()
-    w4 = v.select("row<=", 3).new()
+    w4 = v.select("index<=", 3).new()
     w5 = select.value(v == 1).new()
-    w6 = select.row(v < 4).new()
+    w6 = select.index(v < 4).new()
     assert w1.isequal(result)
     assert w2.isequal(result)
     assert w3.isequal(result)
@@ -663,6 +686,38 @@ def test_select(v):
     assert w6.isequal(result)
 
 
+def test_indexunary_udf(v):
+    def twox_minusthunk(x, row, col, thunk):
+        return 2 * x - thunk
+
+    indexunary.register_new("twox_minusthunk", twox_minusthunk)
+    assert hasattr(indexunary, "twox_minusthunk")
+    assert not hasattr(select, "twox_minusthunk")
+    with pytest.raises(ValueError):
+        select.register_anonymous(twox_minusthunk)
+    expected = Vector.from_values([1, 3, 4, 6], [-2, -2, 0, -4], size=7)
+    result = indexunary.twox_minusthunk(v, 4).new()
+    assert result.isequal(expected)
+    delattr(indexunary, "twox_minusthunk")
+
+    def ii(x, idx, _, thunk):
+        return idx // 2 >= thunk
+
+    select.register_new("ii", ii)
+    assert hasattr(indexunary, "ii")
+    assert hasattr(select, "ii")
+    ii_apply = indexunary.register_anonymous(ii)
+    expected = Vector.from_values([1, 3, 4, 6], [False, False, True, True], size=7)
+    result = ii_apply(v, 2).new()
+    assert result.isequal(expected)
+    ii_select = select.register_anonymous(ii)
+    expected = Vector.from_values([4, 6], [2, 0], size=7)
+    result = ii_select(v, 2).new()
+    assert result.isequal(expected)
+    delattr(indexunary, "ii")
+    delattr(select, "ii")
+
+
 def test_reduce(v):
     s = v.reduce(monoid.plus).new()
     assert s == 4
@@ -821,6 +876,21 @@ def test_reduce_coerce_dtype(v):
     assert t == 5.23
 
 
+@autocompute
+def test_reduce_call_agg(v):
+    assert agg.sum(v) == 4
+    assert agg.sum(v + v) == 8  # handles expression
+    result = agg.max[float](v).new()  # typed agg is callable too
+    assert result.dtype == "FP64"
+    assert result == 2
+    with pytest.raises(ValueError, match="rowwise"):
+        agg.sum(v, rowwise=True)
+    with pytest.raises(ValueError, match="columnwise"):
+        agg.sum(v, columnwise=True)
+    with pytest.raises(TypeError):
+        agg.sum(7)
+
+
 def test_simple_assignment(v):
     # w[:] = v
     w = Vector(v.dtype, v.size)
@@ -1943,9 +2013,7 @@ def test_broadcasting(A, v):
     (A.dup(bool) & v.dup(bool)).new()  # okay
     with pytest.raises(TypeError):
         v += A
-    with pytest.raises(TypeError):
-        binary.minus(v | A)
-    binary.minus(v | A, require_monoid=False)
+    binary.minus(v | A)
 
 
 def test_ewise_union_infix():
@@ -2021,10 +2089,21 @@ def test_lambda_udfs(v):
     result = v.ewise_mult(v, lambda x, y: x + y).new()
     expected = binary.plus(v & v).new()
     assert result.isequal(expected)
-    result = v.ewise_add(v, lambda x, y: x + y, require_monoid=False).new()
+    result = v.ewise_add(v, lambda x, y: x + y).new()
     assert result.isequal(expected)
     # Should we also allow lambdas for monoids with assumed identity of 0?
-    with pytest.raises(TypeError):
-        v.ewise_add(v, lambda x, y: x + y)
+    # with pytest.raises(TypeError):
+    v.ewise_add(v, lambda x, y: x + y)  # now okay
     with pytest.raises(TypeError):
         v.inner(v, lambda x, y: x + y)
+
+
+def test_get(v):
+    assert compute(v.get(0)) is None
+    assert v.get(0, "mittens") == "mittens"
+    assert v.get(1) == 1
+    assert v.get(1, "mittens") == 1
+    assert type(compute(v.get(1))) is int
+    with pytest.raises(ValueError):
+        # Not yet supported
+        v.get([0, 1])
