@@ -10,8 +10,15 @@ from .dtypes import _INDEX, FP64, INT64, lookup_dtype, unify
 from .exceptions import DimensionMismatch, NoValue, check_status
 from .expr import AmbiguousAssignOrExtract, IndexerResolver, Updater
 from .mask import StructuralMask, ValueMask
-from .operator import get_semiring, get_typed_op
-from .scalar import _MATERIALIZE, Scalar, ScalarExpression, _as_scalar, _scalar_index
+from .operator import find_opclass, get_semiring, get_typed_op, op_from_string
+from .scalar import (
+    _MATERIALIZE,
+    Scalar,
+    ScalarExpression,
+    ScalarIndexExpr,
+    _as_scalar,
+    _scalar_index,
+)
 from .utils import (
     _CArray,
     _Pointer,
@@ -30,7 +37,7 @@ def _v_add_m(updater, left, right, op):
     full = Vector(left.dtype, right._ncols, name="v_full")
     full[:] = 0
     temp = left.outer(full, binary.first).new(name="M_temp", mask=updater.kwargs.get("mask"))
-    updater << temp.ewise_add(right, op, require_monoid=False)
+    updater << temp.ewise_add(right, op)
 
 
 def _v_mult_m(updater, left, right, op):
@@ -155,8 +162,6 @@ class Vector(BaseType):
         resolved_indexes = IndexerResolver(self, keys)
         shape = resolved_indexes.shape
         if not shape:
-            from .scalar import ScalarIndexExpr
-
             return ScalarIndexExpr(self, resolved_indexes)
         else:
             return VectorIndexExpr(self, resolved_indexes, *shape)
@@ -375,6 +380,20 @@ class Vector(BaseType):
         # TODO: expose COMPLETE or MATERIALIZE options to the user
         call("GrB_Vector_wait", [self, _MATERIALIZE])
 
+    def get(self, index, default=None):
+        """Get an element at index as a Python scalar.
+
+        If there is no element at ``vector[index]``, then the default value is returned.
+        """
+        expr = self[index]
+        if expr._is_scalar:
+            rv = expr.new().value
+            return default if rv is None else rv
+        raise ValueError(
+            "Bad index in Vector.get(...).  "
+            "A single index should be given, and the result will be a Python scalar."
+        )
+
     @classmethod
     def new(cls, dtype, size=0, *, name=None):
         """
@@ -430,7 +449,7 @@ class Vector(BaseType):
     # to update to trigger a call to GraphBLAS
     #########################################################
 
-    def ewise_add(self, other, op=monoid.plus, *, require_monoid=True):
+    def ewise_add(self, other, op=monoid.plus, *, require_monoid=None):
         """
         GrB_Vector_eWiseAdd
 
@@ -438,9 +457,8 @@ class Vector(BaseType):
 
         Default op is monoid.plus.
 
-        Unless explicitly disabled, this method requires a monoid (directly or from a semiring).
-        The reason for this is that binary operators can create very confusing behavior when
-        only one of the two elements is present.
+        *Warning*: using binary operators can create very confusing behavior
+        when only one of the two elements is present.
 
         Examples:
             - binary.minus where left=N/A and right=4 yields 4 rather than -4 as might be expected
@@ -449,10 +467,17 @@ class Vector(BaseType):
 
         The behavior is caused by grabbing the non-empty value and using it directly without
         performing any operation. In the case of `gt`, the non-empty value is cast to a boolean.
-        For these reasons, users are required to be explicit when choosing this surprising behavior.
         """
         from .matrix import Matrix, MatrixExpression, TransposedMatrix
 
+        if require_monoid is not None:
+            warnings.warn(
+                "require_monoid keyword is deprecated; "
+                "future behavior will be like `require_monoid=False`",
+                DeprecationWarning,
+            )
+        else:
+            require_monoid = False
         method_name = "ewise_add"
         other = self._expect_type(
             other, (Vector, Matrix, TransposedMatrix), within=method_name, argname="other", op=op
@@ -661,8 +686,19 @@ class Vector(BaseType):
         """
         method_name = "apply"
         extra_message = (
-            "apply only accepts UnaryOp with no scalars or BinaryOp with `left` or `right` scalar."
+            "apply only accepts UnaryOp with no scalars or BinaryOp with `left` or `right` scalar"
+            "or IndexUnaryOp with `right` thunk."
         )
+        if isinstance(op, str):
+            op = op_from_string(op)
+        op, opclass = find_opclass(op)
+        if opclass in {"IndexUnaryOp", "SelectOp"}:
+            # Provide default value for index unary
+            if right is None:
+                right = False  # most basic form of 0 when unifying dtypes
+            if left is not None:
+                raise TypeError("Do not pass `left` when applying IndexUnaryOp")
+
         if left is None and right is None:
             op = get_typed_op(op, self.dtype, kind="unary")
             self._expect_op(
@@ -690,7 +726,7 @@ class Vector(BaseType):
                         op=op,
                     )
             op = get_typed_op(op, left.dtype, self.dtype, is_left_scalar=True, kind="binary")
-            if op.opclass == "Monoid":
+            if opclass == "Monoid":
                 op = op.binaryop
             else:
                 self._expect_op(
@@ -713,7 +749,7 @@ class Vector(BaseType):
             expr_repr = "{1.name}.apply({op}, left={0._expr_name})"
         elif left is None:
             if type(right) is not Scalar:
-                dtype = self.dtype if self.dtype._is_udt else None
+                dtype = self.dtype if (self.dtype._is_udt and not op.is_positional) else None
                 try:
                     right = Scalar.from_value(right, dtype, is_cscalar=None, name="")
                 except TypeError:
@@ -725,26 +761,33 @@ class Vector(BaseType):
                         extra_message="Literal scalars also accepted.",
                         op=op,
                     )
-            op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
-            if op.opclass == "Monoid":
-                op = op.binaryop
-            else:
-                self._expect_op(
-                    op,
-                    "BinaryOp",
-                    within=method_name,
-                    argname="op",
-                    extra_message=extra_message,
+            if opclass in {"IndexUnaryOp", "SelectOp"}:
+                op = get_typed_op(
+                    op, self.dtype, right.dtype, is_right_scalar=True, kind="indexunary"
                 )
+                cfunc_method = "IndexOp"
+            else:
+                op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
+                cfunc_method = "BinaryOp2nd"
+                if opclass == "Monoid":
+                    op = op.binaryop
+                else:
+                    self._expect_op(
+                        op,
+                        "BinaryOp",
+                        within=method_name,
+                        argname="op",
+                        extra_message=extra_message,
+                    )
             if right._is_cscalar:
                 if right.dtype._is_udt:
                     dtype_name = "UDT"
                     right = _Pointer(right)
                 else:
                     dtype_name = right.dtype.name
-                cfunc_name = f"GrB_Vector_apply_BinaryOp2nd_{dtype_name}"
+                cfunc_name = f"GrB_Vector_apply_{cfunc_method}_{dtype_name}"
             else:
-                cfunc_name = "GrB_Vector_apply_BinaryOp2nd_Scalar"
+                cfunc_name = f"GrB_Vector_apply_{cfunc_method}_Scalar"
             args = [self, right]
             expr_repr = "{0.name}.apply({op}, right={1._expr_name})"
         else:
@@ -1191,6 +1234,7 @@ class VectorExpression(BaseExpression):
     ewise_mult = wrapdoc(Vector.ewise_mult)(property(_automethods.ewise_mult))
     ewise_union = wrapdoc(Vector.ewise_union)(property(_automethods.ewise_union))
     gb_obj = wrapdoc(Vector.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Vector.get)(property(_automethods.get))
     inner = wrapdoc(Vector.inner)(property(_automethods.inner))
     isclose = wrapdoc(Vector.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Vector.isequal)(property(_automethods.isequal))
@@ -1263,6 +1307,7 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
     ewise_mult = wrapdoc(Vector.ewise_mult)(property(_automethods.ewise_mult))
     ewise_union = wrapdoc(Vector.ewise_union)(property(_automethods.ewise_union))
     gb_obj = wrapdoc(Vector.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Vector.get)(property(_automethods.get))
     inner = wrapdoc(Vector.inner)(property(_automethods.inner))
     isclose = wrapdoc(Vector.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Vector.isequal)(property(_automethods.isequal))
